from constants import LOGGING_PATH
from datetime import datetime
import subprocess


def shell_cmd(command:str) -> str:
    """
    Executes a command in terminal
    Returns the output as a string
    """

    p = subprocess.Popen(command, stdout=subprocess.PIPE, shell=True) 
    output, error = p.communicate()

    output_string = output.decode().replace('\n', '')
    return output_string


def get_service_pid(service:str) -> int:
    """
    Returns the PID of a service
    If a service is not running, its PID is 0
    """

    command = f"systemctl show --property MainPID --value {service}"
    return int(shell_cmd(command))


def get_ip_address(connection: str) -> str:
    """
    Returns the IP address as a string | ex: '10.0.4.1'
    Or an empty string if the IP address isn't found

    Connection: eth0 / wlan0 / usb0
    """

    command = f"ifconfig {connection}"+" | grep 'inet ' | awk '{print $2}'"
    return shell_cmd(command)


def get_ip_address_priority() -> str:
    """
    Returns the first IP address found (eth0, wlan0, or usb0)
    Or an empty string if no IP addresses are found
    """

    for connection in ['eth0', 'wlan0', 'usb0']:
        address = get_ip_address(connection)
        if address: return address

    return ''


def ip_address_to_int(ip_address:str) -> int:
    """
    ip_address is a string of 4 numbers separated by '.'
    example input: '10.0.4.1'
    returns: 167,773,185

    10*(256^3) + 0*(256^2) + 4*(256^1) + 1*(256^0) = 167,773,185

    Returns -1 if input is invalid
    """

    ip_address = ip_address.split('.')
    if len(ip_address) != 4: return -1

    ip_int = 0
    for i, n in enumerate(ip_address):
        if not n.isnumeric(): return -1
        ip_int += int(n)*256**(3-i)

    return ip_int


def log(msg:str, print_msg=True):
    """Writes message to /home/pi/.log/BiG.log"""

    dt = datetime.now().strftime('%y-%m-%d %H:%M:%S')
    with open(LOGGING_PATH, 'a') as f:
        f.write(f'{dt} | {msg}\n')

    if print_msg: print(msg)
