from functions import log, shell_cmd
from constants import API_BASE_URL
from database import Database
from api import API
import os


class Update:

    def __init__(self):
        # Connect to local sqlite database
        self.db = Database()

        # For making API calls
        self.api = API(self.db)

        if self.update_available():
            self.download_and_update()
        
        self.db.close()


    def update_available(self) -> bool:

        self.current_version = self.get_current_version()
        self.updated_version = self.get_updated_version()

        log(f'Current software version: {self.current_version} | Newest software version: {self.updated_version}')

        if self.updated_version is None:
            log('Software update cancelled - API call error')
            return False
        
        return self.current_version < self.updated_version
    

    def get_current_version(self):

        query = "SELECT value FROM config WHERE key = 'softwareVersion'"
        current_version = self.db.select(query)

        return current_version

    
    def get_updated_version(self):

        root = self.api.api_call(API_BASE_URL+'getBiGBerryVersion')
        newest_version = root.find('BiGBerry/softwareVersion')

        if newest_version is None: return None
        else: return newest_version.text


    def download_and_update(self):

        log(f'Updating software from version {self.current_version} to {self.updated_version}...')
        
        # Step 0. Remove temp directory (if it exists)
        path = '/home/pi/temp'
        if os.path.isdir(path): shell_cmd(f'sudo rm -r {path}')

        for command in [

            # Step 1. Make temp directory
            f'sudo mkdir {path}',
            
            # Step 2. Download zip to directory
            f'sudo wget docs.smtresearch.ca/BiGBerry-Python.zip -P {path}',
            
            # Step 3. Unzip in directory
            f'sudo unzip {path}/BiGBerry-Python.zip -d {path}',
            
            # Step 4. Run bash script to update BiGBerry
            f'sudo /bin/bash {path}/update-BiGBerry',
            
            # Step 5. Remove directory
            f'sudo rm -r {path}'

        ]: shell_cmd(f'{command}')
    
        # Step 6. Update software version in local database
        self.db.execute(f"UPDATE config SET value = '{self.updated_version}' WHERE key = 'softwareVersion'")
        
        log(f'Software updated from {self.current_version} to {self.updated_version}')




if __name__ == '__main__':
    """
    This script will check for a software update
    by comparing the software version in the API response from Analytics
    to the software version in the local database on the TiG

    To change the software version in the API response, edit the file
    /home/smt/analytics2/api/index.php

    If the software version in the API response is newer,
    (for example, 2.1.0 is newer than 2.0.8)
    then this script will do the following:

    0. Remove temp directory (if it exists) 
    1. Make temp directory
    2. Download BiGBerry-Python.zip to temp directory
        -This file is downloaded from docs.smtresearch.ca
        -It is located in /var/www/documents/files in Analytics
    3. Unzip BiGBerry-Python.zip in temp directory
    4. Run bash script update-BiGBerry
        -This script performs the update
        -It comes with BiGBerry-Python.zip and is unique to each update
    5. Remove temp directory
    6. Update software version in config table of local database
    """

    Update()
