<?php

require_once 'includes/status_messages.php';
require_once 'config.php';
require_once 'app/lib/system.php';
require_once RASPI_CONFIG.'/raspap.php';

/**
 * Find the version of the Raspberry Pi
 * Currently only used for the system information page but may useful elsewhere
 */

function RPiVersion()
{
    // Lookup table from http://www.raspberrypi-spy.co.uk/2012/09/checking-your-raspberry-pi-board-version/
    $revisions = array(
    '0002' => 'Model B Revision 1.0',
    '0003' => 'Model B Revision 1.0 + ECN0001',
    '0004' => 'Model B Revision 2.0 (256 MB)',
    '0005' => 'Model B Revision 2.0 (256 MB)',
    '0006' => 'Model B Revision 2.0 (256 MB)',
    '0007' => 'Model A',
    '0008' => 'Model A',
    '0009' => 'Model A',
    '000d' => 'Model B Revision 2.0 (512 MB)',
    '000e' => 'Model B Revision 2.0 (512 MB)',
    '000f' => 'Model B Revision 2.0 (512 MB)',
    '0010' => 'Model B+',
    '0013' => 'Model B+',
    '0011' => 'Compute Module',
    '0012' => 'Model A+',
    'a01041' => 'a01041',
    'a21041' => 'a21041',
    '900092' => 'PiZero 1.2',
    '900093' => 'PiZero 1.3',
    '9000c1' => 'PiZero W',
    'a02082' => 'Pi 3 Model B',
    'a22082' => 'Pi 3 Model B',
    'a32082' => 'Pi 3 Model B',
    'a52082' => 'Pi 3 Model B',
    'a020d3' => 'Pi 3 Model B+',
    'a220a0' => 'Compute Module 3',
    'a020a0' => 'Compute Module 3',
    'a02100' => 'Compute Module 3+',
    'a03111' => 'Model 4B Revision 1.1 (1 GB)',
    'b03111' => 'Model 4B Revision 1.1 (2 GB)',
    'c03111' => 'Model 4B Revision 1.1 (4 GB)'
    );

    $cpuinfo_array = '';
    exec('cat /proc/cpuinfo', $cpuinfo_array);
    $rev = trim(array_pop(explode(':', array_pop(preg_grep("/^Revision/", $cpuinfo_array)))));
    if (array_key_exists($rev, $revisions)) {
        return $revisions[$rev];
    } else {
        exec('cat /proc/device-tree/model', $model);
        if (isset($model[0])) {
            return $model[0];
        } else {
            return 'Unknown Device';
        }
    }
}

function intToStr($syncTimer)
{
    # Takes input syncTimer which is an integer representing the sync timer in seconds
    # Returns a string. ex) input: 3754 | output: 1 hour(s), 2 minute(s), 34 second(s)  

    $hours = intdiv($syncTimer, 3600);

    $syncTimer -= $hours*3600;
    $minutes = intdiv($syncTimer, 60);

    $syncTimer -= $minutes*60;
    $seconds = $syncTimer;

    $syncTimerStr = "";

    if ($hours   > 0){$syncTimerStr .= "$hours hour(s) ";}
    if ($minutes > 0){$syncTimerStr .= "$minutes minute(s) ";}
    if ($seconds > 0){$syncTimerStr .= "$seconds second(s) ";}

    return $syncTimerStr;
}

function DisplaySystem($db)
{    
    $syncTimerInt  = $db->query("SELECT value FROM config WHERE key = 'syncTimer'")->fetchArray()[0];
    $commissioned  = $db->query("SELECT value FROM config WHERE key = 'commissioned'")->fetchArray()[0];
    $clearInterval = $db->query("SELECT value FROM config WHERE key = 'clearInterval'")->fetchArray()[0];
    
    $syncTimerStr = intToStr($syncTimerInt);

    $config = getConfig();
    $user = $_SERVER['PHP_AUTH_USER'] ?? "";
    $pass = $_SERVER['PHP_AUTH_PW']   ?? "";
    $validatedSMT = ($user == $config['smt_user']) && password_verify($pass, $config['smt_pass']); 

    $hostname = shell_exec('cat /etc/hostname');
    $hostnameRequired = (substr_replace($hostname, '', -1) == "raspberrypi") ? 1 : 0;

    $status = new StatusMessages();

    if (isset($_POST['updateTimer'])){
        $hours   = (isset($_POST['hours'])   && trim($_POST['hours'])   != "") ? $_POST['hours']   : 0;
        $minutes = (isset($_POST['minutes']) && trim($_POST['minutes']) != "") ? $_POST['minutes'] : 0;
        $seconds = (isset($_POST['seconds']) && trim($_POST['seconds']) != "") ? $_POST['seconds'] : 0;

        $syncTimerInt = $hours*3600 + $minutes*60 + $seconds;

        if ($syncTimerInt < 600 || $syncTimerInt > 23*3600){
            $status->addMessage("Sync Timer cannot be less than 10 minutes or greater than 23 hours", 'warning');
        }else{
            $syncTimerStr = intToStr($syncTimerInt);
            $db->query("UPDATE config SET value = $syncTimerInt WHERE key = 'syncTimer'");
            $status->addMessage('Preferences updated');
        }
    }
    elseif (isset($_POST['dontDeleteSyncedData'])){
        $clearInterval = -1;
        $db->query("UPDATE config SET value = -1 WHERE key = 'clearInterval'");
        $status->addMessage('Preferences updated');
    }
    elseif (isset($_POST['updateClearInterval'])){
        if (isset($_POST['clearInterval']) && trim($_POST['clearInterval']) != ""){
            $clearInterval = $_POST['clearInterval'];
            $db->query("UPDATE config SET value = $clearInterval WHERE key = 'clearInterval'");
            $status->addMessage('Preferences updated');
        }
        else{$status->addMessage('Must enter number of days', 'warning');}
    }
    elseif (isset($_POST['commission']) && $commissioned == 0){
        $commission = 1;

        if ($hostnameRequired){
            if (isset($_POST['serialNum']) && trim($_POST['serialNum']) != ""){
                $hostname = 'tig'.$_POST['serialNum'];
            }else{
                $status->addMessage('Must enter serial number', 'warning');
                $commission = 0;
            }
        }
        
        $projectID = (isset($_POST['projectID']) && trim($_POST['projectID']) != "") ? $_POST['projectID'] : 0;
        $jobID = (isset($_POST['jobID']) && trim($_POST['jobID']) != "") ? $_POST['jobID'] : 0;

        if ($projectID == 0 || $jobID == 0){
            $status->addMessage('Must enter project ID and job ID', 'warning');
            $commission = 0;
        }
        
        if ($commission){
            if ($hostnameRequired){ exec('sudo bigberry setUser www-data'); }
            
            $path = '/home/pi/python-scripts/commission.py';
            # Executing the command below could take a while
            exec("python3 $path --gwName=$hostname --projectID=$projectID --jobID=$jobID");

            $status->addMessage('Commission finished - Check logs');
        }
    }
    elseif (isset($_POST['decommission']) && $commissioned == 1){
        $unserialize = isset($_POST['unserialize']) ? 1 : 0;

        $path = '/home/pi/python-scripts/commission.py';
        # Executing the command below could take a while
        exec("python3 $path --unserialize=$unserialize");

        $status->addMessage('Decommission finished - Check logs');
    }
    elseif (isset($_POST['SaveLanguage'])) {
        if (isset($_POST['locale'])) {
            $_SESSION['locale'] = $_POST['locale'];
            $status->addMessage('Language setting saved', 'success');
        }
    }
    elseif (isset($_POST['systemReboot'])) {
        $status->addMessage("System Rebooting", "danger", false);
        $result = shell_exec("sudo /sbin/reboot");
    }
    elseif (isset($_POST['systemShutdown'])) {
        $status->addMessage("System Shutting Down", "danger", false);
        $result = shell_exec("sudo /sbin/shutdown -h now");
    }

    if (!RASPI_MONITOR_ENABLED) {
        if (isset($_POST['SaveServerSettings'])) {
            $good_input = true;
            // Validate server port
            if (isset($_POST['serverPort'])) {
                if (strlen($_POST['serverPort']) > 4 || !is_numeric($_POST['serverPort'])) {
                    $status->addMessage('Invalid value for port number', 'danger');
                    $good_input = false;
                } else {
                    $serverPort = escapeshellarg($_POST['serverPort']);
               }
            }
            // Validate server bind address
            $serverBind = escapeshellarg('');
            if ($_POST['serverBind'] && $_POST['serverBind'] !== null ) {
                if (!filter_var($_POST['serverBind'], FILTER_VALIDATE_IP)) {
                    $status->addMessage('Invalid value for bind address', 'danger');
                    $good_input = false;
                } else {
                    $serverBind = escapeshellarg($_POST['serverBind']);
                }
            }
            // Save settings
            if ($good_input) {
                exec("sudo /etc/raspap/lighttpd/configport.sh $serverPort $serverBind " .RASPI_LIGHTTPD_CONFIG. " ".$_SERVER['SERVER_NAME'], $return);
                foreach ($return as $line) {
                    $status->addMessage($line, 'info');
                }
            }
        }
    }

    exec('cat '. RASPI_LIGHTTPD_CONFIG, $return);
    $conf = ParseConfig($return);
    $serverPort = $conf['server.port'];
    $serverBind = str_replace('"', '',$conf['server.bind']);

    // define locales
    $arrLocales = array(
        'en_GB.UTF-8' => 'English',
        'cs_CZ.UTF-8' => 'Čeština',
        'zh_TW.UTF-8' => '正體中文 (Chinese traditional)',
        'zh_CN.UTF-8' => '简体中文 (Chinese simplified)',
        'da_DK.UTF-8' => 'Dansk',
        'de_DE.UTF-8' => 'Deutsch',
        'es_MX.UTF-8' => 'Español',
        'fi_FI.UTF-8' => 'Finnish',
        'fr_FR.UTF-8' => 'Français',
        'el_GR.UTF-8' => 'Ελληνικά',
        'id_ID.UTF-8' => 'Indonesian',
        'it_IT.UTF-8' => 'Italiano',
        'ja_JP.UTF-8' => '日本語 (Japanese)',
        'ko_KR.UTF-8' => '한국어 (Korean)',
        'nl_NL.UTF-8' => 'Nederlands',
        'pl_PL.UTF-8' => 'Polskie',
        'pt_BR.UTF-8' => 'Português',
        'ru_RU.UTF-8' => 'Русский',
        'ro_RO.UTF-8' => 'Română',
        'sv_SE.UTF-8' => 'Svenska',
        'tr_TR.UTF-8' => 'Türkçe',
        'vi_VN.UTF-8' => 'Tiếng Việt (Vietnamese)'
    );

    #fetch system status variables.
    $system = new \RaspAP\System\Sysinfo;

    $uptime   = $system->uptime();
    $cores    = $system->processorCount();
    $os       = $system->operatingSystem();
    $kernel   = $system->kernelVersion();

    // mem used
    $memused  = $system->usedMemory();
    $memused_status = "primary";
    if ($memused > 90) {
        $memused_status = "danger";
        $memused_led = "service-status-down";
    } elseif ($memused > 75) {
        $memused_status = "warning";
        $memused_led = "service-status-warn";
    } elseif ($memused >  0) {
        $memused_status = "success";
        $memused_led = "service-status-up";
    }

    // cpu load
    $cpuload = $system->systemLoadPercentage();
    if ($cpuload > 90) {
        $cpuload_status = "danger";
    } elseif ($cpuload > 75) {
        $cpuload_status = "warning";
    } elseif ($cpuload >=  0) {
        $cpuload_status = "success";
    }

    // cpu temp
    $cputemp = $system->systemTemperature();
    if ($cputemp > 70) {
        $cputemp_status = "danger";
        $cputemp_led = "service-status-down";
    } elseif ($cputemp > 50) {
        $cputemp_status = "warning";
        $cputemp_led = "service-status-warn";
    } else {
        $cputemp_status = "success";
        $cputemp_led = "service-status-up";
    }

    // hostapd status
    $hostapd = $system->hostapdStatus();
    if ($hostapd[0] == 1) {
        $hostapd_status = "active";
        $hostapd_led = "service-status-up";
    } else {
        $hostapd_status = "inactive";
        $hostapd_led = "service-status-down";
    }

    $syncTimerStr = "TiG is set to sync every $syncTimerStr";
    if ($clearInterval == -1){
        $clearIntvStr = "TiG is set to not delete any old synced data";
    }else{
        $clearIntvStr = "TiG is set to delete synced data older than $clearInterval days (every time the TiG syncs)";
    }

    echo renderTemplate("system", compact(
        "arrLocales",
        "status",
        "serverPort",
        "serverBind",
        "hostname",
        "uptime",
        "cores",
        "os",
        "kernel",
        "memused",
        "memused_status",
        "memused_led",
        "cpuload",
        "cpuload_status",
        "cputemp",
        "cputemp_status",
        "cputemp_led",
        "hostapd",
        "hostapd_status",
        "hostapd_led",
        "syncTimerStr",
        "clearIntvStr",
        "commissioned",
        "validatedSMT",
        "hostnameRequired"
    ));
}
